DeserializeError

Struct DeserializeError 

pub struct DeserializeError {
    pub span: Option<Span>,
    pub path: Option<Path>,
    pub kind: DeserializeErrorKind,
}
Error produced by the format deserializer.

This struct contains span and path information at the top level, with a kind field describing the specific error.

Fields

span: Option<Span>

Source span where the error occurred (if available).

path: Option<Path>

Path through the type structure where the error occurred.

kind: DeserializeErrorKind

The specific kind of error.

Implementations

Source

impl DeserializeError

pub fn set_span(self, span: Span) -> DeserializeError

Add span information to this error.

pub fn set_path(self, path: Path) -> DeserializeError

Add path information to this error.

pub const fn path(&self) -> Option<&Path>

Get the path where the error occurred, if available.

pub const fn span(&self) -> Option<&Span>

Get the span where the error occurred, if available.

pub fn with_path(self, new_path: Path) -> DeserializeError

Add path information to an error (consumes and returns the modified error).