pub struct DeserializeError {
pub span: Option<Span>,
pub path: Option<Path>,
pub kind: DeserializeErrorKind,
}Expand description
Error produced by the format deserializer.
This struct contains span and path information at the top level,
with a kind field describing the specific error.
Fields
span: Option<Span>Source span where the error occurred (if available).
path: Option<Path>Path through the type structure where the error occurred.
kind: DeserializeErrorKindThe specific kind of error.
Implementations
Sourceimpl DeserializeError
impl DeserializeError
Sourcepub fn set_span(self, span: Span) -> DeserializeError
pub fn set_span(self, span: Span) -> DeserializeError
Add span information to this error.
Sourcepub fn set_path(self, path: Path) -> DeserializeError
pub fn set_path(self, path: Path) -> DeserializeError
Add path information to this error.
Sourcepub fn with_path(self, new_path: Path) -> DeserializeError
pub fn with_path(self, new_path: Path) -> DeserializeError
Add path information to an error (consumes and returns the modified error).